==> shoplazza-cli-0.1.8.tgz: package/lib/checkout/api.js <==
const Axios = require('axios');
const path = require('path');
const fs = require('fs');
const FormData = require('form-data');
const loading = require('loading-cli');
const { openAipVersion } = require('./config');
const { isDebug } = require('./console');
const { getProjectConfig } = require('./util');
const chalk = require('chalk');

const FILE_SIGN_URL = '/checkout_extensions/file/sign';
const CREATE_URL = '/checkout_extensions/create';
const COMMIT_URL = '/checkout_extensions/commit';
const LIST_URL = '/checkout_extensions/list';
const VERSION_LIST_URL = '/checkout_extensions/version/list';
const DEPLOY_URL = '/checkout_extensions/deploy';
const UNDEPLOY_URL = '/checkout_extensions/undeploy';
const PREVIEW_URL = '/checkout_extensions/preview';

let configJson = undefined;

const request = new Axios.create();

request.interceptors.request.use((config) => {
  if (config.data instanceof FormData) {
    Object.assign(config.headers, config.data.getHeaders());
  }
  if (!configJson) {
    configJson = getProjectConfig();
  }
  config.headers['Access-Token'] = configJson.token;
  if (!config.url.startsWith('http')) {
    config.url = path.join(configJson.store, openAipVersion, config.url);
  }

  if (isDebug()) {
    console.log(`\n==> ${config.method}: ${config.url}`);
  }
  return config;
});

request.interceptors.response.use(
  (response) => {
    if (isDebug()) {
      console.log(`\n<== ${response.status}: ${response.config.url}`);
    }
    return response;
  },
  (error) => {
    if (isDebug()) {
      console.log(`\n<== error ${error.response.status}: ${error.response.config.url}`);
    }
    if (!error.response) {
      throw chalk.red('Network error, please check your connection.');
    }
    if (error.response?.status == 403) {
      return Promise.reject(new Error('Token permission failure'));
    }
    return Promise.reject(error);
  }
);

async function upload(path, name) {
  const form = new FormData();
  await request(`${FILE_SIGN_URL}?key=${name}`)
    .then((data) => {
      return data.data;
    })
    .then((data) => {
      const url = data.write_host;
      form.append('policy', data.policy);
      form.append('OSSAccessKeyId', data.access_id);
      form.append('success_action_status', 200);
      form.append('signature', data.sign);
      form.append('x-oss-forbid-overwrite', 'true');
      form.append('key', name);
      form.append('file', fs.createReadStream(path));
      return request.post(`https:${url}`, form, { headers: form.getHeaders() });
    });
  loading('succeed upload').succeed();
}

async function uploadDir(dirPath, files) {
  await Promise.all(
    files.map((file) => {
      return upload(`${dirPath}/${file}`, `chick-extension/${file}`);
    })
  );
}

module.exports = {
  upload,
  uploadDir,
  getExtensionList: async (params) => {
    const load = loading('Fetch extension list').start();
    try {
      const res = await request(`${LIST_URL}`, {
        params
      });
      load.succeed('Successfully fetched the extension list.');
      return res;
    } catch (error) {
      load.fail('Failed to fetch the extension list.');
      throw error;
    }
  },
  getVersionList: async (params) => {
    const load = loading('Fetch version list').start();
    try {
      const res = await request(`${VERSION_LIST_URL}`, {
        params
      });
      load.succeed('Successfully fetched the version list.');
      return res;
    } catch (error) {
      load.fail('Failed to fetch the version list.');
      throw error;
    }
  },
  pushExtension: async (data, isFirstPush = false) => {
    data = {
      extension: {
        ...data
      }
    };
    const res = await request({ url: isFirstPush ? CREATE_URL : COMMIT_URL, method: 'POST', data });
    if (res.data?.status === 3 && res.data?.message === 'INVALID_VERSION') {
      throw 'During repeated pushes, the version number must be greater than the previous version number.';
    }
    return res;
  },
  deployExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    return request({ url: DEPLOY_URL, method: 'POST', data });
  },
  undeployExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    return request({ url: UNDEPLOY_URL, method: 'POST', data });
  },
  previewExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    return request({ url: PREVIEW_URL, method: 'POST', data });
  }
};

==> shoplazza-cli-1.0.2.tgz: package/lib/checkout/api.js <==
const Axios = require('axios');
const path = require('path');
const fs = require('fs');
const FormData = require('form-data');
const loading = require('loading-cli');
const { openAipVersion } = require('./config');
const { isDebug } = require('./console');
const { getProjectConfig } = require('./util');
const chalk = require('chalk');

const FILE_SIGN_URL = '/checkout_extensions/file/sign';
const CREATE_URL = '/checkout_extensions/create';
const COMMIT_URL = '/checkout_extensions/commit';
const LIST_URL = '/checkout_extensions/list';
const VERSION_LIST_URL = '/checkout_extensions/version/list';
const DEPLOY_URL = '/checkout_extensions/deploy';
const UNDEPLOY_URL = '/checkout_extensions/undeploy';
const PREVIEW_URL = '/checkout_extensions/preview';

let configJson = undefined;

const request = new Axios.create();

request.interceptors.request.use((config) => {
  if (config.data instanceof FormData) {
    Object.assign(config.headers, config.data.getHeaders());
  }
  if (!configJson) {
    configJson = getProjectConfig();
  }
  config.headers['Access-Token'] = configJson.token;
  if (!config.url.startsWith('http')) {
    config.url = path.join(configJson.store, openAipVersion, config.url);
  }

  if (isDebug()) {
    console.log(`\n==> ${config.method}: ${config.url}`);
  }
  return config;
});

const handleResponseError = (response)=>{
  if (response.data?.status === 3 && response.data?.message === 'INVALID_ARGUMENT') {
    throw `Invalid argument at ${response.config.url}`;
  }else if(response.data?.status === 13 && response.data?.message === 'INTERNAL_ERROR'){
    throw `Internal error at ${response.config.url}`;
  }
}

request.interceptors.response.use(
  (response) => {
    if (isDebug()) {
      console.log(`\n<== ${response.status}: ${response.config.url}`);
    }
    handleResponseError(response);
    return response;
  },
  (error) => {
    if (isDebug()) {
      console.log(`\n<== error ${error.response.status}: ${error.response.config.url}`);
    }
    if (!error.response) {
      throw chalk.red('Network error, please check your connection.');
    }
    if (error.response?.status == 403) {
      return Promise.reject(new Error('Token permission failure'));
    }
    return Promise.reject(error);
  }
);

async function upload(path, name) {
  const form = new FormData();
  await request(`${FILE_SIGN_URL}?key=${name}`)
    .then((data) => {
      return data.data;
    })
    .then((data) => {
      const url = data.write_host;
      form.append('policy', data.policy);
      form.append('OSSAccessKeyId', data.access_id);
      form.append('success_action_status', 200);
      form.append('signature', data.sign);
      form.append('x-oss-forbid-overwrite', 'true');
      form.append('key', name);
      form.append('file', fs.createReadStream(path));
      return request.post(`https:${url}`, form, { headers: form.getHeaders() });
    });
  loading('succeed upload').succeed();
}

async function uploadDir(dirPath, files) {
  await Promise.all(
    files.map((file) => {
      return upload(`${dirPath}/${file}`, `chick-extension/${file}`);
    })
  );
}

module.exports = {
  upload,
  uploadDir,
  getExtensionList: async (params) => {
    const load = loading('Fetch extension list').start();
    try {
      const res = await request(`${LIST_URL}`, {
        params
      });
      load.succeed('Successfully fetched the extension list.');
      return res;
    } catch (error) {
      load.fail('Failed to fetch the extension list.');
      throw error;
    }
  },
  getVersionList: async (params) => {
    const load = loading('Fetch version list').start();
    try {
      const res = await request(`${VERSION_LIST_URL}`, {
        params
      });
      load.succeed('Successfully fetched the version list.');
      return res;
    } catch (error) {
      load.fail('Failed to fetch the version list.');
      throw error;
    }
  },
  pushExtension: async (data, isFirstPush = false) => {
    data = {
      extension: {
        ...data
      }
    };
    const res = await request({ url: isFirstPush ? CREATE_URL : COMMIT_URL, method: 'POST', data });
    if (res.data?.status === 3 && res.data?.message === 'INVALID_VERSION') {
      throw 'During repeated pushes, the version number must be greater than the previous version number.';
    }
    return res;
  },
  deployExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    return request({ url: DEPLOY_URL, method: 'POST', data });
  },
  undeployExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    return request({ url: UNDEPLOY_URL, method: 'POST', data });
  },
  previewExtension: async (data) => {
    data = {
      extension: {
        ...data
      }
    };
    const res = await request({ url: PREVIEW_URL, method: 'POST', data });
    if (res.data?.status === 14 && res.data?.message === 'ITEM_UNAVAILABLE') {
      throw 'Failed to generate a preview URL because your store currently has no available items.';
    }
    return res;
  }
};
